Introducing Mozilla.ai: Investing in trustworthy AI
Description: We’re committing $30M to build Mozilla.ai: A startup — and a community — building a trustworthy, independent, and open-source AI ecosystem. We’re o

Introducing Mozilla.ai: Investing in trustworthy AI | The Mozilla Blog
Skip to content

#### Search

Search for:
Mozilla

# Introducing Mozilla.ai: Investing in trustworthy AI

March 22, 2023
Mark Surman

We’re committing $30M to build Mozilla.ai: A startup — and a community — building a trustworthy, independent, and open-source AI ecosystem.

We’re only three months into 2023, and it’s already clear what one of the biggest stories of the year is: AI. AI has seized the public’s attention like Netscape did in 1994, and the iPhone did in 2007.

New tools like Stable Diffusion and the just-released GPT-4 are reshaping not just how we think about the internet, but also communication and creativity and society at large. Meanwhile, relatively older AI tools like the recommendation engines that power YouTube, TikTok and other social apps are growing even more powerful — and continuing to influence billions of lives.

This new wave of AI has generated excitement, but also significant apprehension. We aren’t just wondering What’s possible? and How can people benefit? We’re also wondering What could go wrong? and How can we address it? Two decades of social media, smartphones and their consequences have made us leery.

Mozilla has been asking these questions about AI for a while now — sketching out a vision for trustworthy AI, mobilizing our community to document what’s broken and investing in startups that are trying to create more responsible AI.

We’ve learned that this coming wave of AI (and also the last one) has tremendous potential to enrich people’s lives. But it will only do so if we design the technology very differently — if we put human agency and the interests of users at the core, and if we prioritize transparency and accountability. The AI inflection point that we’re in right now offers a real opportunity to build technology with different values, new incentives and a better ownership model.

The good news: We’ve met literally thousands of founders, engineers, scientists, designers, artists and activists who are taking this approach to AI. Smart, dedicated people are building open-source AI technology, testing out new approaches to auditing and figuring out how to build ‘trust’ into AI in the real world.

The less good news: We don’t see this happening amongst the big tech and cloud companies with the most power and influence. Meanwhile, these incumbents continue to consolidate their control over the market.

In short: Some people are starting to do things differently, but the most significant work (and investment) is happening the same old way. We want to change this.

So, today we are announcing Mozilla.ai: A startup — and a community — that will build a trustworthy and independent open-source AI ecosystem. Mozilla will make an initial $30M investment in the company.

The vision for Mozilla.ai is to make it easy to develop trustworthy AI products. We will build things and hire / collaborate with people that share our vision: AI that has agency, accountability, transparency and openness at its core. Mozilla.ai will be a space outside big tech and academia for like-minded founders, developers, scientists, product managers and builders to gather. We believe that this group of people, working collectively, can turn the tide to create an independent, decentralized and trustworthy AI ecosystem — a real counterweight to the status quo.

Mozilla.ai’s initial focus? Tools that make generative AI safer and more transparent. And, people-centric recommendation systems that don’t misinform or undermine our well-being. We’ll share more on these — and what we’re building — in the coming months.

This new company will be led by Managing Director Moez Draief. Moez has spent over a decade working on the practical applications of cutting-edge AI as an academic at Imperial College and LSE, and as a chief scientist in industry. Harvard’s Karim Lakhani, Credo’s Navrina Singh and myself will serve as the initial Board of Mozilla.ai.

Later this year, we will announce additional initiatives, partners and events where people can get involved. If you are interested in collaborating, reach out at hello@mozilla.ai.

## Related Articles

Internet Culture

## A civic tech creative on modernizing government sites, MySpace coding and pre-internet memories

Read More
Firefox

## Exploring the Firefox Community on r/firefox

Read More
AI

## How AI is reshaping creativity: Insights from art, tech and policy

Read More
Your e-mail address
Country
Language
Format

HTML Text

I’m okay with Mozilla handling my info as explained in this Privacy Policy.

We will only send you Mozilla-related information.

## Thanks!

If you haven’t previously confirmed a subscription to a Mozilla-related newsletter you may have to do so. Please check your inbox or your spam filter for an e-mail from us.